@@ -5,9 +5,9 @@ has 'key';
 
 sub run {
     my ($self) = @_;
-    my $config = $self->read_file;
+    my $config = $self->read_config;
     delete $config->{twtxt}->{ $self->key };
-    $self->write_file($config);
+    $self->write_config($config);
     return 0;
 }
 
