@@ -4,7 +4,7 @@ use Mojo::Base 'App::txtnix';
 sub run {
     my $self   = shift;
     my @tweets = $self->get_tweets();
-    $self->display_tweets(@tweets);
+    $self->display_tweets( 1, @tweets );
     return 0;
 }
 
