@@ -4,9 +4,11 @@ use Mojo::ByteStream 'b';
 use App::txtnix::Tweet;
 use Path::Tiny;
 use String::ShellQuote qw(shell_quote);
+use Mojo::Date;
 
 has 'text';
 has 'created_at';
+has 'hooks' => sub { 1 };
 
 sub run {
     my ($self) = @_;
@@ -14,7 +16,13 @@ sub run {
     $text = b($text)->decode;
     $text =~ s/\@(\w+)/$self->expand_mention($1)/ge;
 
-    my $time = $self->created_at ? $self->to_epoch( $self->created_at ) : time;
+    my $time =
+        $self->created_at
+      ? $self->to_date( $self->created_at )
+      : Mojo::Date->new();
+
+    die "Can't parse --created-at " . $self->created_at . " as rfc3339.\n"
+      if !defined $time->epoch;
 
     my $tweet = App::txtnix::Tweet->new( text => $text, timestamp => $time );
     my $file = path( $self->twtfile );
@@ -23,12 +31,12 @@ sub run {
     my $pre_hook  = $self->pre_tweet_hook;
     my $post_hook = $self->post_tweet_hook;
     my $twtfile   = shell_quote( $self->twtfile );
-    if ($pre_hook) {
+    if ( $self->hooks && $pre_hook ) {
         $pre_hook =~ s/\Q{twtfile}/$twtfile/ge;
         system($pre_hook) == 0 or die "Can't call pre_tweet_hook $pre_hook.\n";
     }
     $file->append_utf8( $tweet->to_string . "\n" );
-    if ($post_hook) {
+    if ( $self->hooks && $post_hook ) {
         $post_hook =~ s/\Q{twtfile}/$twtfile/ge;
         system($post_hook) == 0
           or die "Can't call post_tweet_hook $post_hook.\n";
